@@ -1,10 +1,12 @@
 package Date::Qreki;
-require Exporter;
-@ISA = qw(Exporter);
-@EXPORT_OK = qw/calc_kyureki get_rokuyou/;
 use warnings;
 use strict;
-our $VERSION = '0.06';
+require Exporter;
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw/calc_kyureki get_rokuyou rokuyou_unicode check_24sekki/;
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
+our $VERSION = '0.07';
+use utf8;
 
 #=========================================================================
 # 旧暦計算サンプルプログラム  $Revision:   1.1  $
@@ -49,6 +51,16 @@ sub get_rokuyou
 	return(($q_mon + $q_day) % 6);
 }
 
+sub rokuyou_unicode
+{
+
+	my ($year,$mon,$day) = @_;
+	my ($tm0,$q_year,$q_mon,$q_day,$uruu,$q_yaer);
+
+	($q_yaer,$uruu,$q_mon,$q_day) = calc_kyureki($year,$mon,$day);
+
+	return (qw/大安 赤口 先勝 友引 先負 仏滅/)[(($q_mon + $q_day) % 6)];
+}
 #=========================================================================
 # 新暦に対応する、旧暦を求める。
 #
